==> qt-creator-opensource-src-4.10.2.zip: qt-creator-opensource-src-4.10.2/src/plugins/qmldesigner/components/timelineeditor/animationcurvedialog.cpp <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "animationcurvedialog.h"

#include <QVBoxLayout>

namespace QmlDesigner {

AnimationCurveDialog::AnimationCurveDialog(QWidget *parent)
    : QDialog(parent)
    , m_editor(nullptr)
{
    setWindowFlag(Qt::WindowContextHelpButtonHint, false);
}

AnimationCurveDialog::AnimationCurveDialog(DesignTools::CurveEditorModel *model, QWidget *parent)
    : QDialog(parent)
    , m_editor(nullptr)
{
    setWindowFlag(Qt::WindowContextHelpButtonHint, false);
    setModel(model);
}

void AnimationCurveDialog::setModel(DesignTools::CurveEditorModel *model)
{
    if (m_editor)
        return;

    m_editor = new DesignTools::CurveEditor(model);

    auto *layout = new QVBoxLayout;
    layout->addWidget(m_editor);
    setLayout(layout);
}

void AnimationCurveDialog::showEvent(QShowEvent *)
{
    m_editor->clearCanvas();
}

} // namespace QmlDesigner

==> qt-creator-opensource-src-4.11.0.zip: qt-creator-opensource-src-4.11.0/src/plugins/qmldesigner/components/timelineeditor/animationcurvedialog.cpp <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "animationcurvedialog.h"

#include <QVBoxLayout>

namespace QmlDesigner {

AnimationCurveDialog::AnimationCurveDialog(QWidget *parent)
    : QDialog(parent)
    , m_editor(nullptr)
{
    setWindowFlag(Qt::WindowContextHelpButtonHint, false);
}

AnimationCurveDialog::AnimationCurveDialog(DesignTools::CurveEditorModel *model, QWidget *parent)
    : QDialog(parent)
    , m_editor(nullptr)
{
    setWindowFlag(Qt::WindowContextHelpButtonHint, false);
    setModel(model);
}

void AnimationCurveDialog::setModel(DesignTools::CurveEditorModel *model)
{
    if (m_editor)
        return;

    m_editor = new DesignTools::CurveEditor(model);

    auto *layout = new QVBoxLayout;
    layout->addWidget(m_editor);
    setLayout(layout);
}

void AnimationCurveDialog::refresh()
{
    if (m_editor)
        m_editor->clearCanvas();
}

} // namespace QmlDesigner
